import { CSSResultGroup, LitElement, TemplateResult } from "lit";
import { BaklavaIcon } from "../../icon/icon-list";
export declare enum CloseSource {
    DurationEnded = "duration-ended",
    CloseButton = "close-button"
}
export type NotificationVariant = "info" | "success" | "warning" | "error";
/**
 * @tag bl-notification-card
 * @summary Baklava Notification Card component
 */
export default class BlNotificationCard extends LitElement {
    static get styles(): CSSResultGroup;
    /**
     * Sets notification caption.
     * @attr caption
     * @type {string}
     * @default ""
     */
    caption: string;
    /**
     * Allows to customize notification icon.
     * True value will display default icon.
     * False value will hide icon.
     * String value will display icon with specified name.
     * @attr icon
     * @type {boolean | BaklavaIcon}
     * @default true
     */
    icon?: boolean | BaklavaIcon;
    /**
     * Sets notification variant.
     * @attr variant
     * @type {NotificationVariant}
     * @default "info"
     */
    variant: NotificationVariant;
    /**
     * Sets notification display duration in minutes.
     * Has no effect if permanent is set to true.
     * @attr closed
     * @type {boolean}
     * @default false
     */
    duration: number;
    /**
     * Prevents notification from being closed automatically.
     * @attr closed
     * @type {boolean}
     * @default false
     */
    permanent: boolean;
    /**
     * Indicates whether the notification is closed.
     */
    closed: boolean;
    /**
     * Dispatches close request event.
     * The notification will not be closed automatically if the event is prevented.
     */
    private onRequestClose;
    /**
     * Dispatches close event.
     * The notification will hidden after the event is dispatched and the closed property is set to true.
     */
    private onClose;
    protected firstUpdated(): void;
    /**
     * Sets up duration animation.
     * The notification will dispatch a closed event after the animation ends.
     */
    private setupDuration;
    private close;
    private handleClose;
    private renderProgress;
    render(): TemplateResult;
}
declare global {
    interface HTMLElementTagNameMap {
        "bl-notification-card": BlNotificationCard;
    }
}
//# sourceMappingURL=bl-notification-card.d.ts.map