import { CSSResultGroup, LitElement, TemplateResult } from "lit";
export type Placement = "top-start" | "top" | "top-end" | "bottom-start" | "bottom" | "bottom-end" | "left-start" | "left" | "left-end" | "right-start" | "right" | "right-end";
/**
 * @tag bl-popover
 * @summary Baklava Popover component
 *
 * @cssproperty [--bl-popover-arrow-display=none] - Sets the display of popovers arrow. Set as `block` to make arrow visible.
 * @cssproperty [--bl-popover-background-color=--bl-color-neutral-full] - Sets the background color of popover.
 * @cssproperty [--bl-popover-border-color=--bl-color-primary-highlight] - Sets the border color of popover.
 * @cssproperty [--bl-popover-border-size=1px] - Sets the border size of popover. You can set it to `0px` to not have a border (if you use a custom background color). Always use with a length unit.
 * @cssproperty [--bl-popover-padding=--bl-size-m] - Sets the padding of popover.
 * @cssproperty [--bl-popbover-border-radius=--bl-size-3xs] - Sets the border radius of popover.
 * @cssproperty [--bl-popover-max-width=100vw] - Sets the maximum width of the popover (including border and padding).
 * @cssproperty [--bl-popover-position=fixed] - Sets the position of popover. You can set it to `absolute` if parent element is a fixed positioned element like drawer or dialog.
 */
export default class BlPopover extends LitElement {
    /**
     * Sets placement of the popover
     */
    placement: Placement;
    /**
     * Sets size of popover same as trigger element
     */
    fitSize: boolean;
    /**
     * Sets the distance between popover and target/trigger element
     */
    offset: number;
    private _popover;
    private arrow;
    /**
     * Fires when the popover is shown
     */
    private onBlPopoverShow;
    /**
     * Fires when popover becomes hidden
     */
    private onBlPopoverHide;
    private popoverAutoUpdateCleanup;
    static get styles(): CSSResultGroup;
    /**
     * Target elements state
     */
    _target: string | Element;
    /**
     * Sets the target element of the popover to align and trigger.
     * It can be a string id of the target element or can be a direct Element reference of it.
     */
    get target(): string | Element;
    set target(value: string | Element);
    /**
     * Visibility state
     */
    private _visible;
    /**
     * Gives the visibility status of the popover
     */
    get visible(): boolean;
    connectedCallback(): void;
    disconnectedCallback(): void;
    /**
     * Shows popover
     */
    show(): void;
    /**
     * Hides popover
     */
    hide(): void;
    render(): TemplateResult;
    private getMiddleware;
    private _handleClickOutside;
    private setPopover;
    private _handlePopoverShowEvent;
    private _handleKeydownEvent;
}
declare global {
    interface HTMLElementTagNameMap {
        "bl-popover": BlPopover;
    }
}
//# sourceMappingURL=bl-popover.d.ts.map