import { CSSResultGroup, LitElement, TemplateResult } from "lit";
import "../button/bl-button";
import { ButtonKind, ButtonSize, ButtonVariant, TargetType } from "../button/bl-button";
import BlDropdownItem from "../dropdown/item/bl-dropdown-item";
import { BaklavaIcon } from "../icon/icon-list";
export declare const blSplitButtonTag = "bl-split-button";
/**
 * @tag bl-split-button
 * @summary Baklava Split Button component
 */
export default class BlSplitButton extends LitElement {
    static get styles(): CSSResultGroup;
    private trigger;
    private _popover;
    private mainButton;
    private dropdownButton;
    private _isPopoverOpen;
    /**
     * Sets the split button label
     */
    label: string;
    /**
     * Sets the split button variant
     */
    variant: Exclude<ButtonVariant, "tertiary">;
    /**
     * Sets the split button kind
     */
    kind: ButtonKind;
    /**
     * Sets the split button size
     */
    size: ButtonSize;
    /**
     * Set link url. If set, split main button will be rendered as anchor tag.
     */
    href: string;
    /**
     * Sets main button as disabled
     */
    disabled: boolean;
    /**
     * Sets loading state of button
     */
    loading: boolean;
    /**
     * Sets the button label for loading status.
     */
    loadingLabel: string;
    /**
     * Sets dropdown button as disabled
     */
    dropdownDisabled: boolean;
    /**
     * Sets the icon name. Shows icon with bl-icon component
     */
    icon?: BaklavaIcon;
    /**
     * Sets the anchor target. Used when `href` is set.
     */
    target?: TargetType;
    /**
     * Sets the type of the button. Set `submit` to use button as the submitter of parent form.
     */
    type: "submit";
    /**
     * Sets button to get keyboard focus automatically
     */
    autofocus: boolean;
    /**
     * Sets the associated form of the button. Use when `type` is set to `submit` and button is not inside the target form.
     */
    form: HTMLFormElement | string;
    /**
     * Fires when dropdown opened
     */
    private onOpen;
    /**
     * Fires when dropdown closed
     */
    private onClose;
    /**
     * Fires when main button click
     */
    private onClick;
    connectedCallback(): void;
    disconnectedCallback(): void;
    firstUpdated(): void;
    get opened(): boolean;
    private _handleClick;
    private _handlePrimaryClick;
    private focusedOptionIndex;
    private handleKeyDown;
    get options(): BlDropdownItem[];
    open(): void;
    close(): void;
    render(): TemplateResult;
}
declare global {
    interface HTMLElementTagNameMap {
        [blSplitButtonTag]: BlSplitButton;
    }
}
//# sourceMappingURL=bl-split-button.d.ts.map